@@ -5,10 +5,12 @@ from myst.client import Client, get_client, set_client
 from myst.core.data.time_array import TimeArray
 from myst.core.time.time import Time
 from myst.core.time.time_delta import TimeDelta
+from myst.models.timing import AbsoluteTiming, RelativeTiming
 from myst.resources.input import Input
 from myst.resources.layer import Layer
 from myst.resources.model import Model
 from myst.resources.operation import Operation
+from myst.resources.policy import ModelFitPolicy, Policy, TimeSeriesRunPolicy
 from myst.resources.project import Project
 from myst.resources.source import Source
 from myst.resources.time_series import TimeSeries
@@ -19,6 +21,7 @@ __version__ = get_package_version()
 
 
 __all__ = [
+    "AbsoluteTiming",
     "authenticate_with_service_account",
     "authenticate",
     "Client",
@@ -27,12 +30,16 @@ __all__ = [
     "Input",
     "Layer",
     "Model",
+    "ModelFitPolicy",
     "Operation",
+    "Policy",
     "Project",
+    "RelativeTiming",
     "settings",
     "Source",
     "Time",
     "TimeArray",
     "TimeDelta",
     "TimeSeries",
+    "TimeSeriesRunPolicy",
 ]
