@@ -1,8 +1,6 @@
 from typing import Optional, Union
 
-from myst.models.absolute_timing import AbsoluteTiming
-from myst.models.relative_timing import RelativeTiming
-from myst.models.timing import Timing
+from myst.models.timing import AbsoluteTiming, RelativeTiming, Timing
 from myst.openapi.models.absolute_timing_create import AbsoluteTimingCreate
 from myst.openapi.models.relative_timing_create import RelativeTimingCreate
 
