@@ -24,10 +24,11 @@ class Client:
     ):
         """A wrapper object providing convenient API access with credentials."""
         # Construct an httpx client so that we can reuse a single TCP connection and configuration.
+        self.base_url = (api_host or settings.MYST_API_HOST).rstrip("/")
         self._client = httpx.Client(
             timeout=timeout or settings.API_TIMEOUT_SEC,
             headers={"User-Agent": self.user_agent},
-            base_url=f"{api_host or settings.MYST_API_HOST}/{self.API_VERSION}",
+            base_url=f"{self.base_url}/{self.API_VERSION}",
         )
         self._credentials = credentials
 
