@@ -9,7 +9,7 @@ class MystClientError(BaseMystError):
     """Generic errors in the Myst client."""
 
 
-class UnauthenticatedError(BaseMystError):
+class UnauthenticatedError(MystClientError):
     """Raised when authentication is missing or fails."""
 
     def __init__(self, message: str) -> None:
@@ -18,6 +18,14 @@ class UnauthenticatedError(BaseMystError):
         self.message = message
 
 
+class NotFound(MystClientError):
+    """The requested resource was not found."""
+
+    def __init__(self, message: str) -> None:
+        super().__init__(message)
+        self.message = message
+
+
 class MystAPIError(BaseMystError):
     """Generic Myst API error."""
 
