@@ -1,3 +1,4 @@
+from functools import singledispatch
 from typing import Any, List, Mapping, Tuple, Union
 from uuid import UUID
 
@@ -11,3 +12,18 @@ Metadata = Mapping[str, Union[str, int, float, bool, None]]
 # Note: This should be a recursive type alias but `mypy` doesn't support that, so use `List[Any]` instead to allow for
 #   an arbitrary amount of nesting.
 ItemOrSlice = Union[Tuple[Union[IntOrStr, List[Any]], ...], List[Any], IntOrStr]
+
+
+@singledispatch
+def to_uuid(uuid: UUIDOrStr) -> UUID:
+    raise NotImplementedError()
+
+
+@to_uuid.register
+def _uuid_to_uuid(uuid: UUID) -> UUID:
+    return uuid
+
+
+@to_uuid.register
+def _str_to_uuid(uuid: str) -> UUID:
+    return UUID(uuid)
