@@ -1,6 +1,5 @@
 from myst.client import Client
-
-from ...models.model_connector_get import ModelConnectorGet
+from myst.openapi.models.model_connector_get import ModelConnectorGet
 
 
 def request_sync(client: Client, uuid: str) -> ModelConnectorGet:
