@@ -1,6 +1,5 @@
 from myst.client import Client
-
-from ...models.model_connector_list import ModelConnectorList
+from myst.openapi.models.model_connector_list import ModelConnectorList
 
 
 def request_sync(client: Client) -> ModelConnectorList:
