@@ -1,6 +1,5 @@
 from myst.client import Client
-
-from ...models.operation_connector_get import OperationConnectorGet
+from myst.openapi.models.operation_connector_get import OperationConnectorGet
 
 
 def request_sync(client: Client, uuid: str) -> OperationConnectorGet:
