@@ -1,6 +1,5 @@
 from myst.client import Client
-
-from ...models.operation_connector_list import OperationConnectorList
+from myst.openapi.models.operation_connector_list import OperationConnectorList
 
 
 def request_sync(client: Client) -> OperationConnectorList:
