@@ -1,7 +1,6 @@
 from myst.client import Client
-
-from ...models.organization_create import OrganizationCreate
-from ...models.organization_get import OrganizationGet
+from myst.openapi.models.organization_create import OrganizationCreate
+from myst.openapi.models.organization_get import OrganizationGet
 
 
 def request_sync(client: Client, json_body: OrganizationCreate) -> OrganizationGet:
