@@ -1,6 +1,5 @@
 from myst.client import Client
-
-from ...models.source_connector_get import SourceConnectorGet
+from myst.openapi.models.source_connector_get import SourceConnectorGet
 
 
 def request_sync(client: Client, uuid: str) -> SourceConnectorGet:
