@@ -1,4 +1,4 @@
-from typing import Optional
+from typing import Any, Optional
 
 from pydantic import Field
 from typing_extensions import Literal
@@ -17,4 +17,6 @@ class ModelFitResultGet(base_model.BaseModel):
     start_time: str
     end_time: str
     as_of_time: str
+    fit_state_url: str
+    inputs: Any
     update_time: Optional[str] = None
