@@ -1,8 +1,7 @@
 from typing import List
 
 from myst.models import base_model
-
-from ..models.operation_connector_get import OperationConnectorGet
+from myst.openapi.models.operation_connector_get import OperationConnectorGet
 
 
 class OperationConnectorList(base_model.BaseModel):
