@@ -1,8 +1,7 @@
 from typing import List
 
 from myst.models import base_model
-
-from ..models.operation_get import OperationGet
+from myst.openapi.models.operation_get import OperationGet
 
 
 class OperationList(base_model.BaseModel):
