@@ -1,8 +1,7 @@
 from typing import List
 
 from myst.models import base_model
-
-from ..models.operation_run_result_get import OperationRunResultGet
+from myst.openapi.models.operation_run_result_get import OperationRunResultGet
 
 
 class OperationRunResultList(base_model.BaseModel):
