@@ -9,6 +9,6 @@ from myst.models import base_model
 class ProjectCreate(base_model.BaseModel):
     """Schema for project create requests."""
 
-    object_: Literal["Project"] = Field(..., alias="object")
     title: str
+    object_: Optional[Literal["Project"]] = Field("Project", alias="object")
     description: Optional[str] = None
