@@ -1,9 +1,8 @@
 from typing import List, Union
 
 from myst.models import base_model
-
-from ..models.input_get import InputGet
-from ..models.layer_get import LayerGet
+from myst.openapi.models.input_get import InputGet
+from myst.openapi.models.layer_get import LayerGet
 
 
 class ProjectEdgesList(base_model.BaseModel):
