@@ -1,8 +1,7 @@
 from typing import List
 
 from myst.models import base_model
-
-from ..models.source_get import SourceGet
+from myst.openapi.models.source_get import SourceGet
 
 
 class SourceList(base_model.BaseModel):
