@@ -7,7 +7,9 @@ from myst.connectors.operation_connector import OperationConnector
 from myst.connectors.source_connector import SourceConnector
 from myst.core.time.time_delta import TimeDelta
 from myst.models.types import AxisLabels, CoordinateLabels, Shape, UUIDOrStr, to_uuid
-from myst.openapi.api.projects import create_project, get_project, list_project_edges, list_project_nodes, list_projects
+from myst.openapi.api.projects import create_project, get_project, list_projects
+from myst.openapi.api.projects.edges import list_project_edges
+from myst.openapi.api.projects.nodes import list_project_nodes
 from myst.openapi.models.deploy_status import DeployStatus
 from myst.openapi.models.input_get import InputGet
 from myst.openapi.models.layer_get import LayerGet
